==> ginkgocadx_2.6.0.0~rc.orig.tar.gz: ginkgocadx-2.6.0.0/src/visualizator/visualizator/vistas/waveformview.cpp <==
/*
 *  
 *  $Id: waveformview.cpp 4316 2011-10-19 14:42:20Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#include <wx/wx.h>
#include <wx/checkbox.h>
#include <wx/filename.h>
#include <wx/file.h>
#include <wx/busyinfo.h>
#include <wx/msgdlg.h>
#include <wx/xml/xml.h>
#include <wx/utils.h>

#include <api/globals.h>
#include <api/math/geometria3d.h>
#include <api/icontroladorherramientas.h>
#include <api/icontroladorvistas.h>
#include <api/icontroladorcarga.h>
#include <api/dicom/imodelodicom.h>
#include <api/dicom/idicomizador.h>
#include <api/icontroladorpermisos.h>
#include <eventos/eventosginkgo.h>

#include <export/iherramientapuntero.h>
#include <export/iherramientaregla.h>
#include <export/iherramientaangulo.h>
#include <export/iherramientanota.h>
#include <export/iherramientamarcado.h>
#include <export/iherramientarejillametrica.h>
#include <export/iherramientaanotacionesesquina.h>
#include <api/imodelointegracion.h>
#include <api/icontroladormodulo.h>
#include <api/icontroladorpermisos.h>
#include <export/iherramientareset.h>
#include "../eventos/visualizatorevents.h"
#include "../estudios/visualizatorstudy.h"

#include <visualizator/widgets/wecg.h>

#include "waveformview.h"
#include "../wxvtk/gwaveformview.h"
#include "../dialogos/contenedorherramientas.h"


#ifdef __DEPRECATED
#undef __DEPRECATED
#endif
#include <vtkDataSetAttributes.h>
#include <vtkAlgorithm.h>
#include <vtkAlgorithmOutput.h>
#include <vtkImageData.h>
#include <hackimageactor.h>
#include <vtkAlgorithmOutput.h>
#include <vtkInformation.h>
#include <vtkCamera.h>

/* Constructor */

GNKVisualizator::WaveFormView::WaveFormView(const GnkPtr<GNKVisualizator::ECGStudy>& estudio) : GNC::GCS::IVista((GnkPtr<GNC::GCS::IContextoEstudio>)estudio), VisualizatorStudy(estudio)
{
	m_Cargada = false;
	
	VisualizatorStudy->Ventana = GVista = new GNKVisualizator::GUI::GWaveformView(this);

	GNC::GCS::IControladorHerramientas* cH = VisualizatorStudy->Entorno->GetControladorHerramientas();

	GNC::GCS::IHerramientaPuntero*             hPuntero = NULL;
	GNC::GCS::IHerramientaRegla*               hRegla = NULL;
	GNC::GCS::IHerramientaAngulo*              hAngulo = NULL;
	GNC::GCS::IHerramientaNota*                hNota = NULL;
	GNC::GCS::IHerramientaAnotacionesEsquina*  hAnotacionesEsquina = NULL;
	GNC::GCS::IHerramientaMarcado*             hMarcado       = NULL;
	GNC::GCS::IHerramientaReset*               hReset = NULL;

	try {
		// Subscribimos la vista al contrato de puntero
		hPuntero = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaPuntero>(GNC::GCS::IHerramientaPuntero::ID);
		if (hPuntero != NULL) {
			GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>* contratablevtk=hPuntero;
			contratablevtk->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de regla
		hRegla = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaRegla>(GNC::GCS::IHerramientaRegla::ID);
		if (hRegla != NULL) {
			hRegla->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de angulo
		hAngulo = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAngulo>(GNC::GCS::IHerramientaAngulo::ID);
		if (hAngulo != NULL) {
			hAngulo->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de marcado
		hMarcado = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaMarcado>(GNC::GCS::IHerramientaMarcado::ID);
		if (hMarcado != NULL) {
			hMarcado->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de hNota
		hNota = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaNota>(GNC::GCS::IHerramientaNota::ID);
		if (hNota != NULL) {
			hNota->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de Anotaciones ventana
		hAnotacionesEsquina = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAnotacionesEsquina>(GNC::GCS::IHerramientaAnotacionesEsquina::ID);
		if (hAnotacionesEsquina != NULL) {
			hAnotacionesEsquina->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de mapas de color
		hReset = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaReset>(GNC::GCS::IHerramientaReset::ID);
		if (hReset != NULL) {
			hReset->Subscribir(this,GVista);
		}	
	}
	catch (GNC::GCS::ControladorHerramientasException& ex) {
		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
	}
}


GNKVisualizator::WaveFormView::~WaveFormView()
{
	GTRACE(">> WaveFormView::~WaveFormView() " << this)

	GNC::GCS::IControladorHerramientas* cH = VisualizatorStudy->Entorno->GetControladorHerramientas();
	GNC::GCS::IHerramientaPuntero*            hPuntero = NULL;
	GNC::GCS::IHerramientaRegla*              hRegla = NULL;
	GNC::GCS::IHerramientaAngulo*             hAngulo = NULL;
	GNC::GCS::IHerramientaNota*               hNota = NULL;
	GNC::GCS::IHerramientaAnotacionesEsquina* hAnotacionesEsquina = NULL;
	GNC::GCS::IHerramientaMarcado*            hMarcado       = NULL;
	GNC::GCS::IHerramientaReset*              hReset = NULL;

	try {
		// Desubscribimos la vista al contrato de puntero
		hPuntero = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaPuntero>(GNC::GCS::IHerramientaPuntero::ID);
		if (hPuntero != NULL) {
			GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>* contratablevtk = hPuntero;
			contratablevtk->DesSubscribirsLosDeLaVista(this);
		}

		// Desubscribimos la vista al contrato de puntero
		hRegla = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaRegla>(GNC::GCS::IHerramientaRegla::ID);
		if (hRegla != NULL) {
			hRegla->DesSubscribirsLosDeLaVista(this);
		}

		// Desubscribimos la vista al contrato de puntero
		hAngulo = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAngulo>(GNC::GCS::IHerramientaAngulo::ID);
		if (hAngulo != NULL) {
			hAngulo->DesSubscribirsLosDeLaVista(this);
		}

		// dessuscribimos la vista al contrato de hNota
		hNota = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaNota>(GNC::GCS::IHerramientaNota::ID);
		if (hNota != NULL) {
			hNota->DesSubscribirsLosDeLaVista(this);
		}

		// desubscribimos la vista al contrato de anotaciones ventana
		hAnotacionesEsquina= cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAnotacionesEsquina>(GNC::GCS::IHerramientaAnotacionesEsquina::ID);
		if (hAnotacionesEsquina != NULL) {
			hAnotacionesEsquina->DesSubscribirsLosDeLaVista(this);
		}

		// dessuscribimos la vista al contrato de marcado
		hMarcado = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaMarcado>(GNC::GCS::IHerramientaMarcado::ID);
		if (hMarcado != NULL) {
			hMarcado->DesSubscribirsLosDeLaVista(this);
		}

		// Subscribimos la vista al contrato de mapas de color
		hReset = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaReset>(GNC::GCS::IHerramientaReset::ID);
		if (hReset != NULL) {
			hReset->DesSubscribirsLosDeLaVista(this);
		}

	}
	catch (GNC::GCS::ControladorHerramientasException& ex) {
		std::cerr << "Error al obtener la herramienta puntero. No se pudo des-subscribir la herramienta: " << ex.getCause() << std::endl;
	}

	GTRACE("<< VistaSimple::~VistaSimple() " << this)
}

//----------------------------------------------------------------------------------------------------
//region Interfaz de Carga


// Comienzo de carga. Metodo sincrono con la interfaz.
void GNKVisualizator::WaveFormView::OnCargaIniciada()
{
}

// Paso 1: Cargar los ficheros en memoria. Metodo NO sincrono con la interfaz.
void GNKVisualizator::WaveFormView::CargarEstudio(GNC::GCS::IComando* pCmdInvocador)
{
	
}

// Finalizacion de la carga. Metodo sincrono con la interfaz.
void GNKVisualizator::WaveFormView::OnCargaFinalizada()
{
	GVista->OnFinishLoad();
}

// Paso 2: Inicializacion del pipeline. Metodo sincrono con la interfaz.
void GNKVisualizator::WaveFormView::IniciarPipeline()
{
	try {
		GVista->InitPipeline();
	}
	catch (const std::bad_alloc&) {
		DetenerPipeline();
		m_Cargada = false;
		throw GNC::GCS::VistaException(_Std("Error: System out of memory. Close some studies to free memory."));
	}
	catch (GNC::GCS::VistaException& ex) {
		DetenerPipeline();
		m_Cargada = false;
		throw ex;
	}

	m_Cargada = true;

	//se conecta el evento Ginkgo
	GNC::GCS::Eventos::EventoModificacionFichero evtModificado;
	evtModificado.SetVista(this);
	VisualizatorStudy->CargarWidgets();

	VisualizatorStudy->IndiceFicheroActivo = 0;
	
	typedef GNC::GCS::Vector3D Vec;

	GVista->ViewImage2D->UpdateImage();
	
	vtkSmartPointer<vtkCamera> cam = GVista->ViewImage2D->GetRenderer()->GetActiveCamera();
	
	Vec focalPoint;
	Vec camPos;
	Vec spacing;
	Vec dims;
	Vec winsize;
	int idims[3];
	int iwinsize[2];

	GVista->ViewInteractor2D->Layout();
	GVista->ViewInteractor2D->GetParent()->Layout();

	GVista->ViewImage2D->GetSpacing(spacing.v);
	GVista->ViewImage2D->GetDimensions(idims);
	GVista->ViewInteractor2D->GetClientSize(&iwinsize[0], &iwinsize[1]);
	//((wxWindowBase* )GVista->ViewInteractor2D)->GetSize();

	dims.x = idims[0];
	dims.y = idims[1];
	winsize.x = iwinsize[0];
	winsize.y = iwinsize[1];
	
	Vec worldViewPort = (spacing * (dims + Vec(1.0, 1.0, 0.0))); // + 1.0 cause pixel centers to pixels edges conversion

	double parallelScale = worldViewPort.y / 2.0;

	GVista->ViewImage2D->SetInitialParallelScale( parallelScale );

	double rel = (winsize.x / winsize.y); // Relacin ancho/alto del viewPort
	
	focalPoint = Vec( rel * (parallelScale), parallelScale, 0.0);
	camPos = focalPoint - Vec(0.0, 0.0, 1.0);

	cam->SetPosition( camPos.v );
	cam->SetFocalPoint( focalPoint.v );	
	cam->SetViewUp(0.0, -1.0, 0.0);
	cam->SetClippingRange(-2.0, 2.0);	

	//lanzo el evento de imagen cargada
	VisualizatorStudy->Entorno->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Eventos::EventoModificacionImagen(this,GNC::GCS::Eventos::EventoModificacionImagen::ImagenCargada));
	VisualizatorStudy->Entorno->GetControladorHerramientas()->RefrescarHerramientas();

	GenerarTitulo();
}

// Parada del pipeline. Metodo sincrono con la interfaz Se invoca en el caso de que ocurra un error de carga.
void GNKVisualizator::WaveFormView::DetenerPipeline()
{
	GVista->StopPipeline();
}

//endregion


bool GNKVisualizator::WaveFormView::SoportaGuardar()
{
	return false;
}

bool GNKVisualizator::WaveFormView::SoportaExportar()
{
	return false;
}

void GNKVisualizator::WaveFormView::OnFocus()
{
	if (!m_Activada) {
		VisualizatorStudy->Entorno->GetControladorVistas()->SolicitarActivarVista(this);
	}
}

void GNKVisualizator::WaveFormView::Activar()
{
	GNC::GCS::IVista::Activar();
	VisualizatorStudy->Modulo->OcultarPaneles();
	GVista->SetFocus();
}


wxWindow* GNKVisualizator::WaveFormView::GetWindow()
{
	return GVista;
}

void GNKVisualizator::WaveFormView::GenerarTitulo()
{
	std::ostringstream ostr;
	std::string valor;

	VisualizatorStudy->GetTagImagenActiva("0010|0010",valor);
	for (std::string::iterator it = valor.begin(); it != valor.end(); it++) {
		if ( *it == '^') {
			*it = ' ';
		}
	}
	ostr << valor.c_str() << ", ";
	VisualizatorStudy->GetTagImagenActiva("0008|1030",valor);
	ostr << valor.c_str();
	if (!valor.empty()) {
		ostr << "/";
	}
	VisualizatorStudy->GetTagImagenActiva("0008|103e",valor);
	ostr << valor.c_str();
	m_Titulo = ostr.str();
}

==> ginkgocadx_2.8.0.4602.orig.tar.gz: ginkgocadx-2.8.0.4602/src/visualizator/visualizator/vistas/waveformview.cpp <==
/*
 *  
 *  $Id: waveformview.cpp 4501 2011-12-20 11:13:41Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#include <wx/wx.h>
#include <wx/checkbox.h>
#include <wx/filename.h>
#include <wx/file.h>
#include <wx/busyinfo.h>
#include <wx/msgdlg.h>
#include <wx/xml/xml.h>
#include <wx/utils.h>

#include <api/globals.h>
#include <api/math/geometria3d.h>
#include <api/icontroladorherramientas.h>
#include <api/icontroladorvistas.h>
#include <api/icontroladorcarga.h>
#include <api/dicom/imodelodicom.h>
#include <api/dicom/idicomizador.h>
#include <api/icontroladorpermisos.h>
#include <eventos/eventosginkgo.h>

#include <export/iherramientapuntero.h>
#include <export/itoolzoom.h>
#include <export/itoolpan.h>
#include <export/iherramientaregla.h>
#include <export/iherramientaangulo.h>
#include <export/iherramientanota.h>
#include <export/iherramientamarcado.h>
#include <export/iherramientarejillametrica.h>
#include <export/iherramientaanotacionesesquina.h>
#include <api/imodelointegracion.h>
#include <api/icontroladormodulo.h>
#include <api/icontroladorpermisos.h>
#include <export/iherramientareset.h>
#include "../eventos/visualizatorevents.h"
#include "../estudios/visualizatorstudy.h"

#include <visualizator/widgets/wecg.h>

#include "waveformview.h"
#include "../wxvtk/gwaveformview.h"
#include "../dialogos/contenedorherramientas.h"


#ifdef __DEPRECATED
#undef __DEPRECATED
#endif
#include <vtkDataSetAttributes.h>
#include <vtkAlgorithm.h>
#include <vtkAlgorithmOutput.h>
#include <vtkImageData.h>
#include <hackimageactor.h>
#include <vtkAlgorithmOutput.h>
#include <vtkInformation.h>
#include <vtkCamera.h>

/* Constructor */

GNKVisualizator::WaveFormView::WaveFormView(const GnkPtr<GNKVisualizator::ECGStudy>& estudio) : GNC::GCS::IVista((GnkPtr<GNC::GCS::IContextoEstudio>)estudio), VisualizatorStudy(estudio)
{
	m_Cargada = false;
	
	VisualizatorStudy->Ventana = GVista = new GNKVisualizator::GUI::GWaveformView(this);

	GNC::GCS::IControladorHerramientas* cH = VisualizatorStudy->Entorno->GetControladorHerramientas();

	GNC::GCS::IHerramientaPuntero*             hPuntero = NULL;
	GNC::GCS::IToolZoom*                       hZoom = NULL;
	GNC::GCS::IToolPan*                        hPan = NULL;
	GNC::GCS::IHerramientaRegla*               hRegla = NULL;
	GNC::GCS::IHerramientaAngulo*              hAngulo = NULL;
	GNC::GCS::IHerramientaNota*                hNota = NULL;
	GNC::GCS::IHerramientaAnotacionesEsquina*  hAnotacionesEsquina = NULL;
	GNC::GCS::IHerramientaMarcado*             hMarcado       = NULL;
	GNC::GCS::IHerramientaReset*               hReset = NULL;

	try {
		// Subscribimos la vista al contrato de puntero
		hPuntero = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaPuntero>(GNC::GCS::IHerramientaPuntero::ID);
		if (hPuntero != NULL) {
			GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>* contratablevtk=hPuntero;
			contratablevtk->Subscribir(this,GVista);
		}

		hZoom = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolZoom>(GNC::GCS::IToolZoom::ID);
		if (hZoom != NULL) {
			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hZoom)->Subscribir(this, GVista);
		}
		
		hPan = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolPan>(GNC::GCS::IToolPan::ID);
		if (hPan != NULL) {
			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hPan)->Subscribir(this, GVista);
		}

		// Subscribimos la vista al contrato de regla
		hRegla = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaRegla>(GNC::GCS::IHerramientaRegla::ID);
		if (hRegla != NULL) {
			hRegla->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de angulo
		hAngulo = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAngulo>(GNC::GCS::IHerramientaAngulo::ID);
		if (hAngulo != NULL) {
			hAngulo->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de marcado
		hMarcado = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaMarcado>(GNC::GCS::IHerramientaMarcado::ID);
		if (hMarcado != NULL) {
			hMarcado->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de hNota
		hNota = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaNota>(GNC::GCS::IHerramientaNota::ID);
		if (hNota != NULL) {
			hNota->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de Anotaciones ventana
		hAnotacionesEsquina = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAnotacionesEsquina>(GNC::GCS::IHerramientaAnotacionesEsquina::ID);
		if (hAnotacionesEsquina != NULL) {
			hAnotacionesEsquina->Subscribir(this,GVista);
		}

		// Subscribimos la vista al contrato de mapas de color
		hReset = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaReset>(GNC::GCS::IHerramientaReset::ID);
		if (hReset != NULL) {
			hReset->Subscribir(this,GVista);
		}	
	}
	catch (GNC::GCS::ControladorHerramientasException& ex) {
		std::cerr << "Error al obtener la herramienta puntero: No se pudo subscribir la herramienta: " << ex.getCause() << std::endl;
	}
}


GNKVisualizator::WaveFormView::~WaveFormView()
{
	GTRACE(">> WaveFormView::~WaveFormView() " << this)

	GNC::GCS::IControladorHerramientas* cH = VisualizatorStudy->Entorno->GetControladorHerramientas();
	GNC::GCS::IHerramientaPuntero*            hPuntero = NULL;
	GNC::GCS::IToolZoom*                      hZoom = NULL;
	GNC::GCS::IToolPan*                       hPan = NULL;
	GNC::GCS::IHerramientaRegla*              hRegla = NULL;
	GNC::GCS::IHerramientaAngulo*             hAngulo = NULL;
	GNC::GCS::IHerramientaNota*               hNota = NULL;
	GNC::GCS::IHerramientaAnotacionesEsquina* hAnotacionesEsquina = NULL;
	GNC::GCS::IHerramientaMarcado*            hMarcado       = NULL;
	GNC::GCS::IHerramientaReset*              hReset = NULL;

	try {
		// Desubscribimos la vista al contrato de puntero
		hPuntero = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaPuntero>(GNC::GCS::IHerramientaPuntero::ID);
		if (hPuntero != NULL) {
			GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>* contratablevtk = hPuntero;
			contratablevtk->DesSubscribirsLosDeLaVista(this);
		}

		hZoom = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolZoom>(GNC::GCS::IToolZoom::ID);
		if (hZoom != NULL) {
			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hZoom)->DesSubscribirsLosDeLaVista(this);
		}
		
		hPan = cH->ObtenerHerramientaConcreta<GNC::GCS::IToolPan>(GNC::GCS::IToolPan::ID);
		if (hPan != NULL) {
			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hPan)->DesSubscribirsLosDeLaVista(this);
		}

		// Desubscribimos la vista al contrato de puntero
		hRegla = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaRegla>(GNC::GCS::IHerramientaRegla::ID);
		if (hRegla != NULL) {
			hRegla->DesSubscribirsLosDeLaVista(this);
		}

		// Desubscribimos la vista al contrato de puntero
		hAngulo = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAngulo>(GNC::GCS::IHerramientaAngulo::ID);
		if (hAngulo != NULL) {
			hAngulo->DesSubscribirsLosDeLaVista(this);
		}

		// dessuscribimos la vista al contrato de hNota
		hNota = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaNota>(GNC::GCS::IHerramientaNota::ID);
		if (hNota != NULL) {
			hNota->DesSubscribirsLosDeLaVista(this);
		}

		// desubscribimos la vista al contrato de anotaciones ventana
		hAnotacionesEsquina= cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAnotacionesEsquina>(GNC::GCS::IHerramientaAnotacionesEsquina::ID);
		if (hAnotacionesEsquina != NULL) {
			hAnotacionesEsquina->DesSubscribirsLosDeLaVista(this);
		}

		// dessuscribimos la vista al contrato de marcado
		hMarcado = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaMarcado>(GNC::GCS::IHerramientaMarcado::ID);
		if (hMarcado != NULL) {
			hMarcado->DesSubscribirsLosDeLaVista(this);
		}

		// Subscribimos la vista al contrato de mapas de color
		hReset = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaReset>(GNC::GCS::IHerramientaReset::ID);
		if (hReset != NULL) {
			hReset->DesSubscribirsLosDeLaVista(this);
		}

	}
	catch (GNC::GCS::ControladorHerramientasException& ex) {
		std::cerr << "Error al obtener la herramienta puntero. No se pudo des-subscribir la herramienta: " << ex.getCause() << std::endl;
	}

	GTRACE("<< VistaSimple::~VistaSimple() " << this)
}

//----------------------------------------------------------------------------------------------------
//region Interfaz de Carga


// Comienzo de carga. Metodo sincrono con la interfaz.
void GNKVisualizator::WaveFormView::OnCargaIniciada()
{
}

// Paso 1: Cargar los ficheros en memoria. Metodo NO sincrono con la interfaz.
void GNKVisualizator::WaveFormView::CargarEstudio(GNC::GCS::IComando* pCmdInvocador)
{
	
}

// Finalizacion de la carga. Metodo sincrono con la interfaz.
void GNKVisualizator::WaveFormView::OnCargaFinalizada()
{
	GVista->OnFinishLoad();
}

// Paso 2: Inicializacion del pipeline. Metodo sincrono con la interfaz.
void GNKVisualizator::WaveFormView::IniciarPipeline()
{
	try {
		GVista->InitPipeline();
	}
	catch (const std::bad_alloc&) {
		DetenerPipeline();
		m_Cargada = false;
		throw GNC::GCS::VistaException(_Std("Error: System out of memory. Close some studies to free memory."));
	}
	catch (GNC::GCS::VistaException& ex) {
		DetenerPipeline();
		m_Cargada = false;
		throw ex;
	}

	m_Cargada = true;

	//se conecta el evento Ginkgo
	GNC::GCS::Eventos::EventoModificacionFichero evtModificado;
	evtModificado.SetVista(this);
	VisualizatorStudy->CargarWidgets();

	VisualizatorStudy->IndiceFicheroActivo = 0;
	
	typedef GNC::GCS::Vector3D Vec;

	GVista->ViewImage2D->UpdateImage();
	
	vtkSmartPointer<vtkCamera> cam = GVista->ViewImage2D->GetRenderer()->GetActiveCamera();
	
	Vec focalPoint;
	Vec camPos;
	Vec spacing;
	Vec dims;
	Vec winsize;
	int idims[3];
	int iwinsize[2];

	GVista->ViewInteractor2D->Layout();
	GVista->ViewInteractor2D->GetParent()->Layout();

	GVista->ViewImage2D->GetSpacing(spacing.v);
	GVista->ViewImage2D->GetDimensions(idims);
	GVista->ViewInteractor2D->GetClientSize(&iwinsize[0], &iwinsize[1]);
	//((wxWindowBase* )GVista->ViewInteractor2D)->GetSize();

	dims.x = idims[0];
	dims.y = idims[1];
	winsize.x = iwinsize[0];
	winsize.y = iwinsize[1];
	
	Vec worldViewPort = (spacing * (dims + Vec(1.0, 1.0, 0.0))); // + 1.0 cause pixel centers to pixels edges conversion

	double parallelScale = worldViewPort.y / 2.0;

	GVista->ViewImage2D->SetInitialParallelScale( parallelScale );

	double rel = (winsize.x / winsize.y); // Relacin ancho/alto del viewPort
	
	focalPoint = Vec( rel * (parallelScale), parallelScale, 0.0);
	camPos = focalPoint - Vec(0.0, 0.0, 1.0);

	cam->SetPosition( camPos.v );
	cam->SetFocalPoint( focalPoint.v );	
	cam->SetViewUp(0.0, -1.0, 0.0);
	cam->SetClippingRange(-2.0, 2.0);	

	//lanzo el evento de imagen cargada
	VisualizatorStudy->Entorno->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Eventos::EventoModificacionImagen(this,GNC::GCS::Eventos::EventoModificacionImagen::ImagenCargada));
	VisualizatorStudy->Entorno->GetControladorHerramientas()->RefrescarHerramientas();

	GenerarTitulo();
}

// Parada del pipeline. Metodo sincrono con la interfaz Se invoca en el caso de que ocurra un error de carga.
void GNKVisualizator::WaveFormView::DetenerPipeline()
{
	GVista->StopPipeline();
}

//endregion


bool GNKVisualizator::WaveFormView::SoportaGuardar()
{
	return false;
}

bool GNKVisualizator::WaveFormView::SoportaExportar()
{
	return false;
}

void GNKVisualizator::WaveFormView::OnFocus()
{
	if (!m_Activada) {
		VisualizatorStudy->Entorno->GetControladorVistas()->SolicitarActivarVista(this);
	}
}

void GNKVisualizator::WaveFormView::Activar()
{
	GNC::GCS::IVista::Activar();
	VisualizatorStudy->Modulo->OcultarPaneles();
	GVista->SetFocus();
}


wxWindow* GNKVisualizator::WaveFormView::GetWindow()
{
	return GVista;
}

void GNKVisualizator::WaveFormView::GenerarTitulo()
{
	std::ostringstream ostr;
	std::string valor;

	VisualizatorStudy->GetTagImagenActiva("0010|0010",valor);
	for (std::string::iterator it = valor.begin(); it != valor.end(); it++) {
		if ( *it == '^') {
			*it = ' ';
		}
	}
	ostr << valor.c_str() << ", ";
	VisualizatorStudy->GetTagImagenActiva("0008|1030",valor);
	ostr << valor.c_str();
	if (!valor.empty()) {
		ostr << "/";
	}
	VisualizatorStudy->GetTagImagenActiva("0008|103e",valor);
	ostr << valor.c_str();
	m_Titulo = ostr.str();
}
